#########################################
DBHT, OWA Weights and Auxiliary Functions
#########################################

.. raw:: html

    <a href='https://ko-fi.com/B0B833SXD' target='_blank'><img height='36'style='border:0px;height:36px;' src='https://cdn.ko-fi.com/cdn/kofi1.png?v=2' border='0' alt='Buy Me a Coffee at ko-fi.com' /></a>

The DBHT module has functions that allows us to use the Direct Bubble Hierarchical Tree (DBHT) :cite:`d-Song`, a new linkage method; and the j-LoGo :cite:`d-jLogo` covariance estimation method.  

The OwaWeights module has functions that allows us to build the weights of some special cases of the OWA Portfolio optimization model :cite:`d-Cajas3`.

The AuxFunctions module has some auxiliary functions that are used in other modules.

DBHT Methods
============

.. automodule:: DBHT
   :members:
   :private-members:
   :member-order: bysource

OWA Weights Functions
=====================

.. automodule:: OwaWeights
   :members:
   :private-members:
   :member-order: bysource

Auxiliary Functions
===================

.. automodule:: AuxFunctions
   :members:
   :private-members:
   :member-order: bysource


Bibliography
============

.. bibliography:: biblio.bib
   :style: unsrt
   :labelprefix: D
   :keyprefix: d-